pub struct ImportLibrary { /* private fields */ }Expand description
Windows import library generator
Implementations
Sourceimpl ImportLibrary
impl ImportLibrary
Sourcepub fn new(
def: &str,
machine: MachineType,
flavor: Flavor,
) -> Result<Self, Error>
pub fn new( def: &str, machine: MachineType, flavor: Flavor, ) -> Result<Self, Error>
Create new import library generator from module definition text content
Sourcepub fn new_arm64x(
def: &str,
native_def: &str,
flavor: Flavor,
) -> Result<Self, Error>
pub fn new_arm64x( def: &str, native_def: &str, flavor: Flavor, ) -> Result<Self, Error>
Create new ARM64X import library generator from two module definition
text contents: def describes the ARM64EC/x64-compatible exports and
native_def describes the pure ARM64 exports. The resulting archive
can be linked from both ARM64 and ARM64EC consumers.
Sourcepub fn from_def(def: ModuleDef, machine: MachineType, flavor: Flavor) -> Self
pub fn from_def(def: ModuleDef, machine: MachineType, flavor: Flavor) -> Self
Create new import library generator from ModuleDef
Sourcepub fn from_defs(
def: ModuleDef,
native_def: Option<ModuleDef>,
machine: MachineType,
flavor: Flavor,
) -> Self
pub fn from_defs( def: ModuleDef, native_def: Option<ModuleDef>, machine: MachineType, flavor: Flavor, ) -> Self
Create new import library generator from a primary ModuleDef and an
optional native ModuleDef. The native def is only meaningful for
MachineType::ARM64X; for other machine types it is ignored.
Sourcepub fn import_name(&self) -> &str
pub fn import_name(&self) -> &str
Get import library name